@@ -87,6 +87,7 @@ class PartitionFetcher(object):
                  queryPartitionCleint=None, commitOffsetClient=None, messageProcessor=None,
                  messageReader=None, simpleConsumer=None, outerCheckPoint=None):
         self.synchronizedLock = threading.Lock()
+        self.update_stateLock = threading.Lock()
         self.consumerGroup = consumerGroup
         self.topicTalosResourceName = topicTalosResourceName
         self.partitionId = partitionId
@@ -198,44 +199,49 @@ class PartitionFetcher(object):
     def get_cur_state(self):
         return self.curState
 
-    @synchronized
     def update_state(self, targetState=None):
-        self.logger.info("PartitionFetcher for Partition: " + str(self.partitionId)
-                         + " update " + "status from: " + cur_state_to_string(self.curState)
-                         + " to: " + cur_state_to_string(targetState))
-        if targetState == TASK_STATE.INIT:
-            self.logger.error("targetState can nerver be INIT, "
-                              + "updateState error for: " + str(self.partitionId))
-            return False
-        elif targetState == TASK_STATE.LOCKED:
-            if self.curState == TASK_STATE.INIT or self.curState == TASK_STATE.UNLOCKED:
-                self.curState = TASK_STATE.LOCKED
-                return True
-            self.logger.error("targetState is LOCKED, but curState is: "
-                              + cur_state_to_string(self.curState) + " for partition: "
-                              + str(self.partitionId))
-            return False
-        elif targetState == TASK_STATE.UNLOCKING:
-            if self.curState == TASK_STATE.LOCKED:
-                self.curState = TASK_STATE.UNLOCKING
-                return True
-            self.logger.error("targetState is UNLOCKING, but curState is: "
-                              + cur_state_to_string(self.curState) + " for partition: "
-                              + str(self.partitionId))
-            return False
-        elif targetState == TASK_STATE.UNLOCKED:
-            if self.curState == TASK_STATE.UNLOCKING or self.curState == TASK_STATE.LOCKED:
-                self.curState = TASK_STATE.UNLOCKED
-                return True
-            self.logger.error("targetState is UNLOCKED, but curState is: "
-                              + cur_state_to_string(self.curState) + " for partition: "
-                              + str(self.partitionId))
-            return False
-        elif targetState == TASK_STATE.SHUTDOWNED:
-            self.curState = TASK_STATE.SHUTDOWNED
-            return False
-        else:
-            return False
+        self.update_stateLock.acquire()
+        try:
+            self.logger.info("PartitionFetcher for Partition: " + str(self.partitionId)
+                             + " update " + "status from: " + cur_state_to_string(self.curState)
+                             + " to: " + cur_state_to_string(targetState))
+            if targetState == TASK_STATE.INIT:
+                self.logger.error("targetState can nerver be INIT, "
+                                  + "updateState error for: " + str(self.partitionId))
+                return False
+            elif targetState == TASK_STATE.LOCKED:
+                if self.curState == TASK_STATE.INIT or self.curState == TASK_STATE.UNLOCKED:
+                    self.curState = TASK_STATE.LOCKED
+                    return True
+                self.logger.error("targetState is LOCKED, but curState is: "
+                                  + cur_state_to_string(self.curState) + " for partition: "
+                                  + str(self.partitionId))
+                return False
+            elif targetState == TASK_STATE.UNLOCKING:
+                if self.curState == TASK_STATE.LOCKED:
+                    self.curState = TASK_STATE.UNLOCKING
+                    return True
+                self.logger.error("targetState is UNLOCKING, but curState is: "
+                                  + cur_state_to_string(self.curState) + " for partition: "
+                                  + str(self.partitionId))
+                return False
+            elif targetState == TASK_STATE.UNLOCKED:
+                if self.curState == TASK_STATE.UNLOCKING or self.curState == TASK_STATE.LOCKED:
+                    self.curState = TASK_STATE.UNLOCKED
+                    return True
+                self.logger.error("targetState is UNLOCKED, but curState is: "
+                                  + cur_state_to_string(self.curState) + " for partition: "
+                                  + str(self.partitionId))
+                return False
+            elif targetState == TASK_STATE.SHUTDOWNED:
+                self.curState = TASK_STATE.SHUTDOWNED
+                return False
+            else:
+                return False
+        except Exception as e:
+            self.logger.error("update_state func error: " + traceback.format_exc())
+        finally:
+            self.update_stateLock.release()
 
     #
     # conditions for releasePartition:
