@@ -185,7 +185,7 @@ class TalosProducer(object):
                         self.logger.error("addUserMessage global lock wait is interrupt."
                                           + str(traceback.format_exc()))
 
-            if not partitionId:
+            if partitionId is None:
                 self.logger.debug("add_user_message without assign specific partition id for："
                                   + self.topicName)
                 self.do_add_user_message(msgList)
